@@ -344,7 +344,7 @@ post_process_urlencoded (struct MHD_PostProcessor *pp,
             return MHD_YES;     /* no '=' yet */
           buf[pp->buffer_pos] = '\0';   /* 0-terminate key */
           pp->buffer_pos = 0;   /* reset for next key */
-          MHD_http_unescape (buf);
+          MHD_http_unescape (NULL, NULL, buf);
           poff += equals + 1;
           pp->state = PP_ProcessValue;
           pp->value_offset = 0;
@@ -404,7 +404,7 @@ post_process_urlencoded (struct MHD_PostProcessor *pp,
 
           /* unescape */
           xbuf[xoff] = '\0';    /* 0-terminate in preparation */
-          xoff = MHD_http_unescape (xbuf);
+          xoff = MHD_http_unescape (NULL, NULL, xbuf);
           /* finally: call application! */
           if (MHD_NO == pp->ikvi (pp->cls, MHD_POSTDATA_KIND, (const char *) &pp[1],    /* key */
                                   NULL, NULL, NULL, xbuf, pp->value_offset,
