@@ -89,7 +89,12 @@ ahc_echo (void *cls,
   *unused = NULL;
   fd = open ("daemontest_get_sendfile.c", O_RDONLY);
   if (fd == -1)
-    abort ();
+    {
+      fprintf (stderr, "Failed to open `%s': %s\n",
+	       "daemontest_get_sendfile.c",
+	       STRERROR (errno));
+      exit (1);
+    }
   response = MHD_create_response_from_fd (strlen (TESTSTR), fd);
   ret = MHD_queue_response (connection, MHD_HTTP_OK, response);
   MHD_destroy_response (response);
